<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.expertrec.com/
 * @since      1.0.0
 *
 * @package    Expertrecsearch
 * @subpackage Expertrecsearch/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Expertrecsearch
 * @subpackage Expertrecsearch/admin
 * @author     melchi <melchi@expertrec.com>
 */
class Expertrecsearch_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Expertrecsearch_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Expertrecsearch_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/expertrecsearch-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Expertrecsearch_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Expertrecsearch_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/expertrecsearch-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function hook_all() {
	    // error_log('expertrec_event_log [' . current_action() . ']');
	}


	public function expertrec_menu_options() {
		// error_log('expertrec_event_log [' . current_action() . ']');
		add_menu_page(
			'ExpertRec',
			'ExpertRec',
			'manage_options',
			'Expertrec',
			[$this,'expertrec_options_content'],
			plugin_dir_url(__FILE__) . 'images/expertrec.png',
			2.11
		);
	}

	public function expertrec_settings_init() {
		// error_log('expertrec_event_log [' . current_action() . ' - doing option initialization]');
		 // register a new setting for "Expertrec" page
		 $page = 'Expertrec';
		 register_setting( $page, 'expertrec_options' );

		 // register a new section in the "expertrec" page
		$section = 'linking';
		 add_settings_section(
		 $section,
		 __( 'Linking your Site id', $page ),
			 [$this,'expertrec_section_cb'],
		 $page
		 );

		 // register a new field site_id in the $section section, inside the $page page
		 add_settings_field(
		 'site_id', // as of WP 4.6 this value is used only internally
		 // use $args' label_for to populate the id inside the callback
		 __( 'Site ID', $page ),
			 [$this,'expertrec_fields'],
		 $page,
		 $section,
		 [
		 'label_for' => 'site_id',
		 ]
		 );
	}

	public function expertrec_options_content() {
		require_once plugin_dir_path( __FILE__ ) . 'partials/expertrecsearch-admin-display.php';
		// error_log('expertrec_event_log [content rendering called]');
		expertrec_options_page_html();
	}
	public function debuglog($message=null) {
		// error_log("debug log got called");
		echo '<p>from debugger</p>';
		echo $message ?  '<p>' .  $message . '</p>' : '';
	}

	public function expertrec_section_cb( $args ) {
		// error_log("section callback got called");
		?>
		<p id="<?php echo esc_attr( $args['id'] ); ?>"></p>
		<?php
	}

	public function expertrec_fields( $args ) {
		// error_log("field callback got called");
		// get the value of the setting we've registered with register_setting()
		$options = get_option( 'expertrec_options' );
		// output the field
		?>
        <input type="text"
               name="expertrec_options[<?php echo esc_attr( $args['label_for'] ); ?>]"
               value="<?php echo esc_attr($options[ $args['label_for'] ]);?>">
		<?php
	}


	private function callExpertrecApi($page , $method, $caller) {
        // error_log("Trying to talk to expertrec server {$method} from {$caller}");

		$site_id = get_option( 'expertrec_options' )['site_id'];
		$safe_id_in_url = rawurlencode(isset($site_id) ? $site_id : get_option("admin_email"));

		$args = array(
			'method' => $method,
			'timeout' => 10,
			'redirection' => 2,
			'httpversion' => '1.1',
            'blocking' => false,
			);

		$clean_page = rawurlencode($page);
		$url = "http://log.expertrec.com/v2/collect/wordpress/{$safe_id_in_url}?url={$clean_page}&caller={$caller}";
		// error_log("Trying to talk to expertrec server @ {$url} with " . var_export($args, true));
		$response = wp_remote_request( $url, $args );
		if( is_wp_error( $response ) ) {
			error_log( $response->get_error_message());
			return true;
		}
		// error_log("code is {$response['response']['code']}");
		// nothing to do with the response.  hopefully it is ok 200.
		// $response_body = wp_remote_retrieve_body( $response );
		// error_log("Done talking to expertrec server @ {$url} with " . var_export($args, true));
		return true;
	}

	public function addpage($pid, $caller) {
		$page = get_permalink($pid);
	    $this->callExpertrecApi($page, 'POST', $caller);
    }
	function get_draft_permalink( $post_id ) {

		require_once ABSPATH . '/wp-admin/includes/post.php';
		list( $permalink, $postname ) = get_sample_permalink( $post_id );
		error_log("permalink {$permalink} postname {$postname}");

		return str_replace( '%postname%', $postname, $permalink );
	}

    public function removepage($pid, $caller) {
	    $page = $this->get_draft_permalink($pid);
	    $this->callExpertrecApi($page, 'DELETE', $caller);
    }

	public function expertrec_transition_post_status( $new_status, $old_status, $post ) {
	    // error_log("transition_post_status {$old_status} => {$new_status}");
		if ( "publish" == $old_status && "publish" != $new_status ) {
			$this->removepage( $post->ID , 'transition_post_status');
		} else if ( "publish" == $new_status && "publish" != $old_status) {
		    $this->addpage($post->ID, 'transition_post_status');
        }
	}


	public function expertrec_future_to_publish( $post ) {
		// error_log("future_to_publish {$post->post_status}");
		if( "publish" == $post->post_status ) {
			$this->addpage( $post->ID, 'future_to_publish' );
		}
	}

	public function expertrec_save_post( $postId ) {
		$post = get_post( $postId );
		// error_log("save_post {$post->post_status}");
		if( "publish" == $post->post_status ) {
			$this->addpage( $postId , 'save_post');
		} else {
		    $this->removepage($postId,"save_post");
        }
	}

	public function expertrec_trashed_post($postId) {
		// error_log("trashed_post {$postId}");
	    $this->removepage($postId, "trashed_post");
    }
}
